==> jc-1.4.0.tar.gz: javax/swing/JTabbedPane__24ModelListener.h <==
// public class javax.swing.JTabbedPane$ModelListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e78ba066c90ae61c javax_swing_JTabbedPane__24ModelListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JTabbedPane__24ModelListener_H_
#define _JC_javax_swing_JTabbedPane__24ModelListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JTabbedPane$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$sub_refs	_jc_javax_swing_JTabbedPane__24ModelListener$sub_refs;
typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$sub_nonrefs	_jc_javax_swing_JTabbedPane__24ModelListener$sub_nonrefs;
typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$refs	_jc_javax_swing_JTabbedPane__24ModelListener$refs;
typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$nonrefs	_jc_javax_swing_JTabbedPane__24ModelListener$nonrefs;
typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$object	_jc_javax_swing_JTabbedPane__24ModelListener$object;

typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$fields_struct	_jc_javax_swing_JTabbedPane__24ModelListener$fields_struct;
typedef const struct _jc_javax_swing_JTabbedPane__24ModelListener$vmethods	_jc_javax_swing_JTabbedPane__24ModelListener$vmethods;
typedef const struct _jc_javax_swing_JTabbedPane__24ModelListener$vtable	_jc_javax_swing_JTabbedPane__24ModelListener$vtable;
typedef const struct _jc_javax_swing_JTabbedPane__24ModelListener$vtype	_jc_javax_swing_JTabbedPane__24ModelListener$vtype;

// Class fields structure
struct _jc_javax_swing_JTabbedPane__24ModelListener$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JTabbedPane__24ModelListener$fields_struct _jc_javax_swing_JTabbedPane__24ModelListener$class_fields;

// Constructors
extern void _jc_javax_swing_JTabbedPane__24ModelListener$method$_init$c7dc76c74c53492c(_jc_env *, struct _jc_javax_swing_JTabbedPane__24ModelListener$object *, struct _jc_javax_swing_JTabbedPane$object *);

// Virtual methods
extern void _jc_javax_swing_JTabbedPane__24ModelListener$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_JTabbedPane__24ModelListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JTabbedPane__24ModelListener$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_JTabbedPane__24ModelListener$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_JTabbedPane__24ModelListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_JTabbedPane__24ModelListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JTabbedPane__24ModelListener$vmethods	javax_swing_JTabbedPane__24ModelListener;
};

// Vtype
struct _jc_javax_swing_JTabbedPane__24ModelListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JTabbedPane__24ModelListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JTabbedPane__24ModelListener$sub_refs {
	struct _jc_javax_swing_JTabbedPane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JTabbedPane__24ModelListener$refs {
    _jc_javax_swing_JTabbedPane__24ModelListener$sub_refs	javax_swing_JTabbedPane__24ModelListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JTabbedPane__24ModelListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JTabbedPane__24ModelListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JTabbedPane__24ModelListener$sub_nonrefs	javax_swing_JTabbedPane__24ModelListener;
};

// Object instance structure
struct _jc_javax_swing_JTabbedPane__24ModelListener$object {
	_jc_javax_swing_JTabbedPane__24ModelListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JTabbedPane__24ModelListener$vtype	*vtype;
	_jc_javax_swing_JTabbedPane__24ModelListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JTabbedPane__24ModelListener$vtype _jc_javax_swing_JTabbedPane__24ModelListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JTabbedPane__24ModelListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JTabbedPane__24ModelListener$class_object;

#endif	/* _JC_javax_swing_JTabbedPane__24ModelListener_H_ */

==> jc-1.4.6.tar.gz: javax/swing/JTabbedPane__24ModelListener.h <==
// public class javax.swing.JTabbedPane$ModelListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e78ba066c90ae61c javax_swing_JTabbedPane__24ModelListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JTabbedPane__24ModelListener_H_
#define _JC_javax_swing_JTabbedPane__24ModelListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JTabbedPane$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$sub_refs	_jc_javax_swing_JTabbedPane__24ModelListener$sub_refs;
typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$sub_nonrefs	_jc_javax_swing_JTabbedPane__24ModelListener$sub_nonrefs;
typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$refs	_jc_javax_swing_JTabbedPane__24ModelListener$refs;
typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$nonrefs	_jc_javax_swing_JTabbedPane__24ModelListener$nonrefs;
typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$object	_jc_javax_swing_JTabbedPane__24ModelListener$object;

typedef struct _jc_javax_swing_JTabbedPane__24ModelListener$fields_struct	_jc_javax_swing_JTabbedPane__24ModelListener$fields_struct;
typedef const struct _jc_javax_swing_JTabbedPane__24ModelListener$vmethods	_jc_javax_swing_JTabbedPane__24ModelListener$vmethods;
typedef const struct _jc_javax_swing_JTabbedPane__24ModelListener$vtable	_jc_javax_swing_JTabbedPane__24ModelListener$vtable;
typedef const struct _jc_javax_swing_JTabbedPane__24ModelListener$vtype	_jc_javax_swing_JTabbedPane__24ModelListener$vtype;

// Class fields structure
struct _jc_javax_swing_JTabbedPane__24ModelListener$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JTabbedPane__24ModelListener$fields_struct _jc_javax_swing_JTabbedPane__24ModelListener$class_fields;

// Constructors
extern void _jc_javax_swing_JTabbedPane__24ModelListener$method$_init$c7dc76c74c53492c(_jc_env *, struct _jc_javax_swing_JTabbedPane__24ModelListener$object *, struct _jc_javax_swing_JTabbedPane$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JTabbedPane__24ModelListener$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_JTabbedPane__24ModelListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JTabbedPane__24ModelListener$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_JTabbedPane__24ModelListener$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_JTabbedPane__24ModelListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JTabbedPane__24ModelListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JTabbedPane__24ModelListener$vmethods	javax_swing_JTabbedPane__24ModelListener;
};

// Vtype
struct _jc_javax_swing_JTabbedPane__24ModelListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JTabbedPane__24ModelListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JTabbedPane__24ModelListener$sub_refs {
	struct _jc_javax_swing_JTabbedPane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JTabbedPane__24ModelListener$refs {
    _jc_javax_swing_JTabbedPane__24ModelListener$sub_refs	javax_swing_JTabbedPane__24ModelListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JTabbedPane__24ModelListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JTabbedPane__24ModelListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JTabbedPane__24ModelListener$sub_nonrefs	javax_swing_JTabbedPane__24ModelListener;
};

// Object instance structure
struct _jc_javax_swing_JTabbedPane__24ModelListener$object {
	_jc_javax_swing_JTabbedPane__24ModelListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JTabbedPane__24ModelListener$vtype	*vtype;
	_jc_javax_swing_JTabbedPane__24ModelListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JTabbedPane__24ModelListener$vtype _jc_javax_swing_JTabbedPane__24ModelListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JTabbedPane__24ModelListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JTabbedPane__24ModelListener$class_object;

#endif	/* _JC_javax_swing_JTabbedPane__24ModelListener_H_ */
